@@ -49,9 +49,27 @@ def add_images_to_existing_project(session, projnumber):
             if template["name"] == "MovingImage_Template":
                 moving_image_template = template
 
+        interior_shots = [i for i in existing_project['children'] if "INT" in i["name"]]
+        num_exist_int = 0
+
+        if interior_shots is not None and len(interior_shots) > 0:
+            int_folder = interior_shots[0]
+            num_exist_int = len(int_folder["children"])
+            print(f'{existing_project["name"]} already has {num_exist_int} INT images')
+        else:
+            print(
+                f"{existing_project['name']} has no INT images, let's create a folder for them!")
+            int_folder = session.create(
+                "Folder",
+                {
+                    "name": f"{projnumber}_INT",
+                    "parent": existing_project
+                })
+
         while True:
             try:
-                additional_ints = int(input("Enter amount of additional INT images: "))
+                additional_ints = int(
+                    input(f"Enter amount of additional INT images (currently: {num_exist_int}): "))
             except ValueError:
                 print("Sorry, I didn't understand that? Did you type a number?")
                 continue
@@ -64,6 +82,22 @@ def add_images_to_existing_project(session, projnumber):
                 int_artist = select_artist(project_team, users, "Select INT artist")
             else:
                 int_artist = project_team[0]
+        exterior_shots = [i for i in existing_project['children'] if "EXT" in i["name"]]
+        num_existing_ext = 0
+        if exterior_shots is not None and len(exterior_shots) > 0:
+            ext_folder = exterior_shots[0]
+            num_existing_ext = len(ext_folder["children"])
+            print(
+                f'{existing_project["name"]} already has {num_existing_ext} EXT images')
+        else:
+            print(
+                f"{existing_project['name']} has no EXT images, let's create a folder for them!")
+            ext_folder = session.create(
+                "Folder",
+                {
+                    "name": f"{projnumber}_EXT",
+                    "parent": existing_project
+                })
 
         while True:
             try:
@@ -81,6 +115,23 @@ def add_images_to_existing_project(session, projnumber):
                 ext_artist = select_artist(project_team, users, "Select EXT artist")
             else:
                 ext_artist = project_team[0]
+        moving_images = [i for i in existing_project['children']
+                         if "MovingImage" in i["name"]]
+        num_existing_moving = 0
+        if moving_images is not None and len(moving_images) > 0:
+            moving_folder = moving_images[0]
+            num_existing_moving = len(moving_folder["children"])
+            print(
+                f'{existing_project["name"]} already has {num_existing_moving} moving images')
+        else:
+            print(
+                f"{existing_project['name']} has no moving images, let's create a folder for them!")
+            moving_folder = session.create(
+                "Folder",
+                {
+                    "name": f"{projnumber}_MovingImages",
+                    "parent": existing_project
+                })
 
         while True:
             try:
@@ -100,57 +151,6 @@ def add_images_to_existing_project(session, projnumber):
             else:
                 moving_artist = project_team[0]
 
-        interior_shots = [i for i in existing_project['children'] if "INT" in i["name"]]
-        num_exist_int = 0
-        if interior_shots is not None and len(interior_shots) > 0:
-            int_folder = interior_shots[0]
-            num_exist_int = len(int_folder["children"])
-            print(f'{existing_project["name"]} already has {num_exist_int} INT images')
-        else:
-            print(
-                f"{existing_project['name']} has no INT images, let's create a folder for them!")
-            int_folder = session.create(
-                "Folder",
-                {
-                    "name": f"{projnumber}_INT",
-                    "parent": existing_project
-                })
-
-        exterior_shots = [i for i in existing_project['children'] if "EXT" in i["name"]]
-        num_existing_ext = 0
-        if exterior_shots is not None and len(exterior_shots) > 0:
-            ext_folder = exterior_shots[0]
-            num_existing_ext = len(ext_folder["children"])
-            print(
-                f'{existing_project["name"]} already has {num_existing_ext} EXT images')
-        else:
-            print(
-                f"{existing_project['name']} has no EXT images, let's create a folder for them!")
-            ext_folder = session.create(
-                "Folder",
-                {
-                    "name": f"{projnumber}_EXT",
-                    "parent": existing_project
-                })
-
-        moving_images = [i for i in existing_project['children']
-                         if "MovingImage" in i["name"]]
-        num_existing_moving = 0
-        if moving_images is not None and len(moving_images) > 0:
-            moving_folder = moving_images[0]
-            num_existing_moving = len(moving_folder["children"])
-            print(
-                f'{existing_project["name"]} already has {num_existing_moving} moving images')
-        else:
-            print(
-                f"{existing_project['name']} has no moving images, let's create a folder for them!")
-            moving_folder = session.create(
-                "Folder",
-                {
-                    "name": f"{projnumber}_MovingImages",
-                    "parent": existing_project
-                })
-
         # interiors
         num_int = num_exist_int + additional_ints
         for i in range(num_exist_int, num_exist_int + additional_ints):
